Package: geoAr
Title: Argentina's Spatial Data Toolbox
Version: 1.2.2
Authors@R: 
   c( person(given = "Juan Pablo",
           family = "Ruiz Nicolini",
           role = c("aut", "cre", "cph"),
           email = "juanpabloruiznicolini@gmail.com",
           comment = c(ORCID = "0000-0002-3138-6343")), 
      person(given = "Patricio",
           family = "Del Boca",
           role = c("aut"),
           email = "patriciodelboca@gmail.com"),
      person(given = "Juan Gabriel",
           family = "Juara",
           role = c("aut"),
           email = "jg.juara@gmail.com"))
Description: Collection of tools that facilitates data access and workflow for spatial analysis of Argentina. Includes historical information from censuses, administrative limits at different levels of aggregation, location of human settlements, among others. Since it is expected that the majority of users will be Spanish-speaking, the documentation of the package prioritizes this language, although an effort is made to also offer annotations in English. 
License: MIT + file LICENSE
Language: es, en
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
Suggests: testthat, gt, knitr, rmarkdown, geofacet, ggplot2, tibble
Depends: R (>= 4.1.0)
Imports: dplyr, sf, httr2 (>= 1.0.0), promises (>= 1.2.0), assertthat,
        attempt, tidyr, stringr, magrittr, curl, glue, leaflet,
        jsonlite, purrr
URL: https://politicaargentina.github.io/geoAr/,
        https://github.com/PoliticaArgentina/geoAr
BugReports: https://github.com/PoliticaArgentina/geoAr/issues
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-05-07 15:01:36 UTC; UsuarioFundar
Author: Juan Pablo Ruiz Nicolini [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-3138-6343>),
  Patricio Del Boca [aut],
  Juan Gabriel Juara [aut]
Maintainer: Juan Pablo Ruiz Nicolini <juanpabloruiznicolini@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-08 08:20:03 UTC
Built: R 4.6.0; ; 2026-05-08 10:26:40 UTC; unix
