# Generated by roxygen2: do not edit by hand

export("%>%")
export(addArgTiles)
export(add_geo_codes)
export(get_asentamientos)
export(get_bahra)
export(get_calles)
export(get_censo)
export(get_departamentos)
export(get_eph)
export(get_geo)
export(get_geodata_dump)
export(get_grid)
export(get_localidades)
export(get_localidades_censales)
export(get_municipios)
export(get_provincias)
export(get_ubicacion)
export(normalizar_direccion)
export(post_asentamientos_bulk)
export(post_calles_bulk)
export(post_departamentos_bulk)
export(post_direcciones_bulk)
export(post_localidades_bulk)
export(post_localidades_censales_bulk)
export(post_municipios_bulk)
export(post_provincias_bulk)
export(post_ubicacion_bulk)
export(recode_grid)
export(show_arg_codes)
export(show_available_censos)
importFrom(httr2,req_auth_bearer_token)
importFrom(httr2,req_body_json)
importFrom(httr2,req_error)
importFrom(httr2,req_method)
importFrom(httr2,req_perform)
importFrom(httr2,req_perform_parallel)
importFrom(httr2,req_url_query)
importFrom(httr2,request)
importFrom(httr2,resp_body_json)
importFrom(httr2,resp_body_raw)
importFrom(httr2,resp_body_string)
importFrom(httr2,resp_content_type)
importFrom(httr2,resp_has_body)
importFrom(httr2,resp_status)
importFrom(httr2,resp_status_desc)
importFrom(httr2,resp_url)
importFrom(magrittr,"%>%")
importFrom(promises,then)
