#' Base de datos de grillas
#'
#' Grillas de Argentina para usar con \code{facet_geo()}
#'
#'
#' @format Una lista que contiene 25 \emph{data.frames} con 5 variables:
#' \describe{
#'   \item{code_provincia}{identificación del distrito al que pertenece la grilla}
#'   \item{col}{LONGITUD relativa de los distritos de segundo nivel en la grilla asemejando la geografía}
#'   \item{row}{LATITUD relativa de los distritos de segundo nivel en la grilla asemejando la geografía}
#'   \item{code}{código de identificación de cada uno de los distritos que componen la grilla}
#'   \item{name}{nombre de cada uno de los distritos que componen la grilla}
#'
#'   ...
#' }
#'
"grillas_geofacet"
