#*' Listado de geometrías de CENSOS disponibles
#'
#' Un archivo de datos que contiene el listado de las geometrías para los censos disponibles
#'
#' @format Un tibble con 10 filas filas y 1 variables (censo)que funciona como id para usar con \code{\link{get_geo}}
#' \describe{
#'   \item{censo}{ID correspondiente al año del censo de Argentina para descargar poligonos disponibles (1869 - 2010)
#'
#'}}
#'
"censos"
