#' \code{geoAr} package
#'
#' Caja de Herramientas GEO de Argentina
#' See the README on
#' \href{https://github.com/PoliticaArgentina/geoAr#readme}{Github}
#'
#' @docType package
#' @name geoAr
"_PACKAGE"

## quiets concerns of R CMD check re: the .'s that appear in pipelines

if(getRversion() >= "2.15.1")
  utils::globalVariables(c(".",
                           "df",
                           "coddept",
                           "coddepto",
                           "coddepto_censo",
                           "code",
                           "codprov",
                           "codprov_censo",
                           "codprov_iso",
                           "data",
                           "depto",
                           "geo_metadata",
                           "grillas_geofacet",
                           "id",
                           "name",
                           "name_iso",
                           "name_prov",
                           "name_provincia",
                           "nomdepto_censo",
                           "geometry",
                           "provincia",
                           "censos",
                           "cod_depto"))






















