% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/georefar.R
\name{post_departamentos_bulk}
\alias{post_departamentos_bulk}
\title{Enviar Lote de Consultas de Departamentos (POST)}
\usage{
post_departamentos_bulk(queries_list)
}
\arguments{
\item{queries_list}{Lista de listas. Cada lista interna debe contener los parámetros
para una consulta de departamento individual (e.g., list(nombre = "Rosario"), list(provincia = "02")).
Parámetros válidos por consulta: id, nombre, provincia, orden, aplanar, campos, max, exacto.}
}
\value{
Un Data Frame (tibble) con los resultados combinados de todas las consultas.
}
\description{
Permite realizar múltiples búsquedas sobre el listado de departamentos en una sola llamada POST.
Realiza la consulta POST al endpoint /departamentos de georef-ar-api.
}
\examples{
\dontrun{
consultas_deptos <- list(
  list(provincia = "22", nombre = "Ledesma"),
  list(id = "14028")
)
resultados_deptos <- post_departamentos_bulk(queries_list = consultas_deptos)
print(resultados_deptos)
}
}
\references{
\href{https://datosgobar.github.io/georef-ar-api/open-api/#/Recursos/post_departamentos}{georef-ar-api/departamentos POST}
}
