% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/georefar.R
\name{post_ubicacion_bulk}
\alias{post_ubicacion_bulk}
\title{Georreferenciación Inversa para un Lote de Puntos (POST)}
\usage{
post_ubicacion_bulk(queries_list)
}
\arguments{
\item{queries_list}{Lista de listas. Cada lista interna debe contener los parámetros
'lat' y 'lon' para un punto.
Otros parámetros válidos por consulta: aplanar, campos.}
}
\value{
Un Data Frame (tibble) con los resultados combinados de todas las georreferenciaciones.
}
\description{
Permite realizar georreferenciación inversa para múltiples puntos (lat, lon) en una sola llamada POST.
Realiza la consulta POST al endpoint /ubicacion de georef-ar-api.
}
\examples{
\dontrun{
consultas_ubic <- list(
  list(lat = -34.6037, lon = -58.3816), # Buenos Aires
  list(lat = -32.9587, lon = -60.6393)  # Rosario
)
resultados_ubic <- post_ubicacion_bulk(queries_list = consultas_ubic)
print(resultados_ubic)
}
}
\references{
\href{https://datosgobar.github.io/georef-ar-api/open-api/#/Recursos/post_ubicacion}{georef-ar-api/ubicacion POST}
}
