% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/georefar.R
\name{post_municipios_bulk}
\alias{post_municipios_bulk}
\title{Enviar Lote de Consultas de Municipios (POST)}
\usage{
post_municipios_bulk(queries_list)
}
\arguments{
\item{queries_list}{Lista de listas. Cada lista interna debe contener los parámetros
para una consulta de municipio individual.
Parámetros válidos por consulta: id, nombre, provincia, departamento, orden, aplanar, campos, max, exacto.}
}
\value{
Un Data Frame (tibble) con los resultados combinados de todas las consultas.
}
\description{
Permite realizar múltiples búsquedas sobre el listado de municipios en una sola llamada POST.
Realiza la consulta POST al endpoint /municipios de georef-ar-api.
}
\examples{
\dontrun{
consultas_muni <- list(
  list(provincia = "06", nombre = "La Plata"),
  list(id = "540098")
)
resultados_muni <- post_municipios_bulk(queries_list = consultas_muni)
print(resultados_muni)
}
}
\references{
\href{https://datosgobar.github.io/georef-ar-api/open-api/#/Recursos/post_municipios}{georef-ar-api/municipios POST}
}
