% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/georefar.R
\name{post_localidades_bulk}
\alias{post_localidades_bulk}
\title{Enviar Lote de Consultas de Localidades (POST)}
\usage{
post_localidades_bulk(queries_list)
}
\arguments{
\item{queries_list}{Lista de listas. Cada lista interna debe contener los parámetros
para una consulta de localidad individual.
Parámetros válidos por consulta: id, nombre, provincia, departamento, municipio, orden, aplanar, campos, max, exacto.}
}
\value{
Un Data Frame (tibble) con los resultados combinados de todas las consultas.
}
\description{
Permite realizar múltiples búsquedas sobre el listado de localidades en una sola llamada POST.
Realiza la consulta POST al endpoint /localidades de georef-ar-api.
}
\examples{
\dontrun{
consultas_loc <- list(
  list(provincia = "Tucuman", departamento = "Capital"),
  list(id = "22056140000")
)
resultados_loc <- post_localidades_bulk(queries_list = consultas_loc)
print(resultados_loc)
}
}
\references{
\href{https://datosgobar.github.io/georef-ar-api/open-api/#/Recursos/post_localidades}{georef-ar-api/localidades POST}
}
